Pact.Models.V4.AsynchronousMessage
(pact_consumer_ex v0.4.2)
Asynchronous interactions as a sequence of messages
Summary
Functions
Returns the raw content of the asynchronous message as a binary.
Functions
@spec bytes(asyc_message :: Pact.Native.PactConsumer.AsynchronousMessage.t()) :: binary()
Returns the raw content of the asynchronous message as a binary.